@@ -32,7 +32,6 @@
 #include <libanjuta/interfaces/ianjuta-markable.h>
 #include <libanjuta/interfaces/ianjuta-indicable.h>
 #include <libanjuta/interfaces/ianjuta-print.h>
-#include <libanjuta/interfaces/ianjuta-language-support.h>
 #include <libanjuta/interfaces/ianjuta-document.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
@@ -186,7 +185,13 @@ static void sourceview_create_markers(Sourceview* sv)
 
 /* Create tags for highlighting */
 static void sourceview_create_highligth_indic(Sourceview* sv)
-{	
+{
+	char* error_color =
+		anjuta_preferences_get (anjuta_preferences_default(),
+		                        "messages.color.error");
+	char* warning_color =
+		anjuta_preferences_get (anjuta_preferences_default (),
+		                        "messages.color.warning");
 	sv->priv->important_indic = 
 		gtk_text_buffer_create_tag (GTK_TEXT_BUFFER(sv->priv->document),
 									IMPORTANT_INDIC,
@@ -194,14 +199,16 @@ static void sourceview_create_highligth_indic(Sourceview* sv)
 	sv->priv->warning_indic = 
 		gtk_text_buffer_create_tag (GTK_TEXT_BUFFER(sv->priv->document),
 									WARNING_INDIC,
-									"foreground", "#00FF00", 
+									"foreground", warning_color, 
 									"underline", PANGO_UNDERLINE_SINGLE,
 									NULL); 
 	sv->priv->critical_indic = 
 		gtk_text_buffer_create_tag (GTK_TEXT_BUFFER(sv->priv->document),
 									CRITICAL_INDIC,
-									"foreground", "#FF0000", "underline", 
+									"foreground", error_color, "underline", 
 									PANGO_UNDERLINE_ERROR, NULL);
+	g_free (error_color);
+	g_free (warning_color);
 }
 
 static void
@@ -311,6 +318,28 @@ static void on_backspace (GtkTextView* view,
 	g_signal_emit_by_name(G_OBJECT(sv), "update_ui");
 }
 
+static void
+on_line_mark_activated(GtkTextView* view,
+                       GtkTextIter   *iter,
+                       GdkEventButton *event,
+                       Sourceview* sv)
+{
+	/* proceed only if its a double click with left button*/
+	if( (event->button != 1) || (GDK_2BUTTON_PRESS != event->type) ) {
+		return;
+	}
+
+	/* line number starts with 0, so add 1 */
+	gint line_number = LINE_TO_LOCATION(gtk_text_iter_get_line(iter));
+
+	if (!IANJUTA_IS_EDITOR(sv))
+	{
+		return;
+	}
+	g_signal_emit_by_name(G_OBJECT(sv), "line-marks-gutter-clicked", line_number);
+}
+
+
 /* Open / Save stuff */
 
 /* Callback for dialog below */
@@ -639,6 +668,7 @@ sourceview_instance_init(Sourceview* sv)
 					  G_CALLBACK (on_sourceview_hover_over), sv);
 	g_signal_connect_after(G_OBJECT(sv->priv->view), "backspace", 
 					 G_CALLBACK(on_backspace),sv);
+
 	g_object_set (G_OBJECT (sv->priv->view), "has-tooltip", TRUE, NULL);
 	gtk_source_view_set_smart_home_end(GTK_SOURCE_VIEW(sv->priv->view), FALSE);
 	
@@ -733,6 +763,10 @@ sourceview_new(GFile* file, const gchar* filename, AnjutaPlugin* plugin)
 	DEBUG_PRINT("%s", "============ Creating new editor =============");
 	
 	g_signal_emit_by_name (G_OBJECT(sv), "update-ui");
+	g_signal_connect_after(G_OBJECT(sv->priv->view), "line-mark-activated",
+					 G_CALLBACK(on_line_mark_activated),
+					 G_OBJECT(sv)
+					 );
 	
 	return sv;
 }
@@ -2007,7 +2041,7 @@ ilanguage_iface_init (IAnjutaEditorLanguageIface *iface)
 
 static void 
 itips_show (IAnjutaEditorTip *iassist, GList* tips, IAnjutaIterable* ipos,
-            gint char_alignment, GError **err)
+            GError **err)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(iassist);
 	SourceviewCell* cell = SOURCEVIEW_CELL (ipos);
@@ -2148,11 +2182,13 @@ iassist_proposals(IAnjutaEditorAssist* iassist,
 		SourceviewProvider* prov;
 		if (!SOURCEVIEW_IS_PROVIDER (node->data))
 			continue;
+		
 		prov = SOURCEVIEW_PROVIDER(node->data);
-		if (prov->cancelled)
-			continue;
 		if (prov->iprov == provider)
 		{
+			if (prov->cancelled)
+				break;
+
 			GList* prop;
 			GList* items = NULL;
 			for (prop = proposals; prop != NULL; prop = g_list_next(prop))
@@ -2160,7 +2196,7 @@ iassist_proposals(IAnjutaEditorAssist* iassist,
 				IAnjutaEditorAssistProposal* proposal = prop->data;
 				GtkSourceCompletionItem* item;
 				if (proposal->markup)
-				{    	    
+				{
 					item = gtk_source_completion_item_new_with_markup(proposal->markup,
 					                                                  proposal->text,
 					                                                  proposal->icon,
@@ -2172,12 +2208,13 @@ iassist_proposals(IAnjutaEditorAssist* iassist,
 					                                      proposal->text,
 					                                      proposal->icon,
 					                                      proposal->info);
-				}    	                                    
+				}
 				items = g_list_append (items, item);
 				g_object_set_data (G_OBJECT(item), "__data", proposal->data);
 			}
 			gtk_source_completion_context_add_proposals (prov->context, GTK_SOURCE_COMPLETION_PROVIDER(prov),
 			                                             items, finished);
+			break;
 		}
 	}
 }
